@@ -22,7 +22,7 @@
 
 
 
-#if defined __GANN__
+#if defined __GMAIN__
 #define __GNMS__
 
 //Geeks Neural Map Simulator (Function)
@@ -65,16 +65,16 @@ void GNMS(int SimFunc)
         Outputs=OutSocket.GetPins();
         
         //Compute Acceptable Error
-        AccErr=100.0-LearnTH;
+        AccErr=100.0-NewGANN.LearnTH;
         
         //Fill NData With Inputs GSocket Data (Only For Uniform Checks)
         for (i=0;i<Inputs;i++)
             NewData[i]=InSocket.GetPV(i,0);
         
         //Check GMap Simulation Type So As To Set GNeurons Function Type
-        if (GMSType==0)
+        if (NewGANN.GMSType==0)
             GNFT=0;
-        else if (GMSType==1)
+        else if (NewGANN.GMSType==1)
             GNFT=1;
         else
             GNFT=2;
@@ -106,9 +106,9 @@ void GNMS(int SimFunc)
         
         {
         
-            //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
-            GNeuron *GANN;
-            GANN=new GNeuron[MAX_MATRIX];
+            //Create New Geeks Network In Memory (G.A.N.N Matrix)
+            GNeuron *GNet;
+            GNet=new GNeuron[NewGANN.MAX_MATRIX];
             
             printf("\n* Simulation %i *\n\n",n+1);
             
@@ -128,15 +128,15 @@ void GNMS(int SimFunc)
             NLE=0;
             
             //Start Routing Through The Layers
-            for (i=0;i<Layers;i++)
+            for (i=0;i<NewGANN.Layers;i++)
             
             {
             
                 //Get GNeurons Of Current Layer
-                k=GMap[i];
+                k=NewGANN.GMap[i];
                 
                 //Check GMap Connections Type (0:Auto,1:Manual)
-                if (GMCType==0)
+                if (NewGANN.GMCType==0)
                 
                 {
                 
@@ -175,7 +175,7 @@ void GNMS(int SimFunc)
                                 }
                                 
                                 //Give Data To This GNeuron
-                                GANN[GNC].InData(p,Tmp);
+                                GNet[GNC].InData(p,Tmp);
                             
                             }
                         
@@ -191,14 +191,14 @@ void GNMS(int SimFunc)
                             {
                             
                                 //Give Data To This GNeuron
-                                GANN[GNC].InData(p-NLH,GANN[p].OutData());
+                                GNet[GNC].InData(p-NLH,GNet[p].OutData());
                             
                             }
                         
                         }
                         
                         //Enable This GNeuron
-                        GANN[GNC].Enable(GNFT);
+                        GNet[GNC].Enable(GNFT);
                         
                         printf("GNeuron %i Enabled!\n\n",GNC+1);
                     
@@ -233,8 +233,8 @@ void GNMS(int SimFunc)
             
             {
             
-                GMinData[j]=GANN[i].OutData()*OutSocket.GetPV(j,0);
-                GMaxData[j]=GANN[i].OutData()*OutSocket.GetPV(j,1);
+                GMinData[j]=GNet[i].OutData()*OutSocket.GetPV(j,0);
+                GMaxData[j]=GNet[i].OutData()*OutSocket.GetPV(j,1);
                 
                 printf("[GPin %i]\n",j+1);
                 printf("Min:%.1f\n",GMinData[j]);
@@ -277,7 +277,7 @@ void GNMS(int SimFunc)
                 }
                 
                 //Save This G.A.N.N To The GKDB
-                GSaveData(GANN,RegSerNum,n+1);
+                GSaveData(GNet,RegSerNum,n+1);
                 
                 //Print Outputs GSocket
                 printf("----- Outputs GSocket -----\n\n");
@@ -315,22 +315,22 @@ void GNMS(int SimFunc)
                     
                     printf("Error Correction [Output GPin %i]\n\n",i+1);
                     
-                    for (j=0;j<GNNum;j++)
+                    for (j=0;j<NewGANN.GNNum;j++)
                     
                     {
                     
                         GMin=OutSocket.GetPV(i,0);
                         GMax=OutSocket.GetPV(i,1);
                         
-                        if ((GANN[j].OutData()*GMin)<GMin\
-                        OR (GANN[j].OutData()*GMax)>GMax)
+                        if ((GNet[j].OutData()*GMin)<GMin\
+                        OR (GNet[j].OutData()*GMax)>GMax)
                         
                         {
                         
-                            if (GMSType==0 OR GMSType==1)
-                                GErrC(GANN,j,GErr,1);
+                            if (NewGANN.GMSType==0 OR NewGANN.GMSType==1)
+                                GErrC(GNet,j,GErr,1);
                             else
-                                GErrC(GANN,j,GErr,0);
+                                GErrC(GNet,j,GErr,0);
                             
                             k=1;
                         
@@ -347,8 +347,8 @@ void GNMS(int SimFunc)
             
             }
             
-            //Unload G.A.N.N From Memory
-            delete []GANN;
+            //Unload GNet From Memory
+            delete []GNet;
         
         }
         
@@ -368,9 +368,9 @@ void GNMS(int SimFunc)
     
     {
     
-        //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
-        GNeuron *GANN;
-        GANN=new GNeuron[MAX_MATRIX];
+        //Create New Geeks Network In Memory (G.A.N.N Matrix)
+        GNeuron *GNet;
+        GNet=new GNeuron[NewGANN.MAX_MATRIX];
         
         //Run GRMC (User Interaction - Load Offset And RegSerNum)
         GRMC(0);
@@ -407,16 +407,16 @@ void GNMS(int SimFunc)
         n++;
         
         //Read GKDB
-        GReadData(GANN,RegSerNum,Offset,n);
+        GReadData(GNet,RegSerNum,Offset,n);
         
         //Compare User Inputs With G.A.N.N Inputs
         if (UserInp>Inputs)
             GExit(1,"Error:Too Many Inputs For This Registration!\n");
         
 	//Check GMap Simulation Type So As To Set GNeurons Function Type
-	if (GMSType==0)
+	if (NewGANN.GMSType==0)
 	    GNFT=0;
-	else if (GMSType==1)
+	else if (NewGANN.GMSType==1)
 	    GNFT=1;
 	else
 	    GNFT=2;
@@ -431,15 +431,15 @@ void GNMS(int SimFunc)
         NLE=0;
         
         //Start Routing Through The Layers
-        for (i=0;i<Layers;i++)
+        for (i=0;i<NewGANN.Layers;i++)
         
         {
         
             //Get GNeurons Of Current Layer
-            k=GMap[i];
+            k=NewGANN.GMap[i];
             
             //Check GMap Connections Type (0:Auto,1:Manual)
-            if (GMCType==0)
+            if (NewGANN.GMCType==0)
             
             {
             
@@ -460,9 +460,9 @@ void GNMS(int SimFunc)
                         
                         {
                         
-                            GANN[GNC].InData(p-NLH,UserVal[p]);
+                            GNet[GNC].InData(p-NLH,UserVal[p]);
                             printf("Weight %i:%.1f\n",p-NLH+1,\
-                            GANN[GNC].GetWeights(p-NLH));
+                            GNet[GNC].GetWeights(p-NLH));
                         
                         }
                     
@@ -477,16 +477,16 @@ void GNMS(int SimFunc)
                         
                         {
                         
-                            GANN[GNC].InData(p-NLH,GANN[p].OutData());
+                            GNet[GNC].InData(p-NLH,GNet[p].OutData());
                             printf("Weight %i:%.1f\n",p-NLH+1,\
-                            GANN[GNC].GetWeights(p-NLH));
+                            GNet[GNC].GetWeights(p-NLH));
                         
                         }
                     
                     }
                     
                     //Run This GNeuron
-                    GANN[GNC].Run(GNFT);
+                    GNet[GNC].Run(GNFT);
                 
                 }
                 
@@ -520,8 +520,8 @@ void GNMS(int SimFunc)
         {
         
             printf("[GPin %i]\n",i-NLH+1);
-            printf("Min:%.1f\n",GANN[i].OutData()*GMinData[i-NLH]);
-            printf("Max:%1.f\n\n",GANN[i].OutData()*GMaxData[i-NLH]);
+            printf("Min:%.1f\n",GNet[i].OutData()*GMinData[i-NLH]);
+            printf("Max:%1.f\n\n",GNet[i].OutData()*GMaxData[i-NLH]);
         
         }
         
@@ -532,12 +532,12 @@ void GNMS(int SimFunc)
         
         {
         
-            if (GANN[i].OutData()*GMinData[i-NLH]>=GMinData[i-NLH]\
-            AND GANN[i].OutData()*GMaxData[i-NLH]<=GMaxData[i-NLH])
+            if (GNet[i].OutData()*GMinData[i-NLH]>=GMinData[i-NLH]\
+            AND GNet[i].OutData()*GMaxData[i-NLH]<=GMaxData[i-NLH])
             
             {
             
-                if (RunTH<LearnTH)
+                if (NewGANN.RunTH<NewGANN.LearnTH)
                 
                 {
                 
@@ -595,8 +595,8 @@ void GNMS(int SimFunc)
         else
             printf("Finished!\n");
         
-        //Unload G.A.N.N From Memory
-        delete []GANN;
+        //Unload GNet From Memory
+        delete []GNet;
     
     }
 
