@@ -22,7 +22,7 @@
 
 
 
-#if defined __GANN__
+#if defined __GMAIN__
 #define __GRAND__
 
 //Geeks Data Randomizer (Function)
